<?php

namespace Bixo\Employee\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use Bixo\Employee\Actions\LeaveAction;
use Bixo\Employee\Http\Requests\LeaveActionRequest;
use Bixo\Employee\Http\Resources\LeaveResource;
use Bixo\Employee\Models\Leave;

/**
 * Admin web controller class.
 */
class LeaveActionController extends BaseController
{

    /**
     * Action controller function for leave.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LeaveActionRequest $request, Leave $leave, $action)
    {
        try {
            $request = $request->all();
            $leave = LeaveAction::run($action, $leave, $request);

            $data = new LeaveResource($leave);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('employee::leave.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('employee/leave/' . $leave->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('employee/leave/' . $leave->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
