<?php

namespace Bixo\Employee\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Exception;
use Bixo\Employee\Http\Requests\LeaveActionsRequest;
use Bixo\Employee\Actions\LeaveActions;

/**
 * Admin web controller class.
 */
class LeaveActionsController extends BaseController
{

    /**
     * Action controller function for leave.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(LeaveActionsRequest $request, $action)
    {
        try {
            $leave = LeaveActions::run($request, $action);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('employee::leave.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('employee/leave/' . $action))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('employee/leave/' . $action))
                ->redirect();
        }
    }
}
