<?php

namespace Bixo\Employee\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Employee\Events\AttendanceWorkflow as AttendanceWorkflowEvent;
use Bixo\Employee\Notifications\AttendanceWorkflow as AttendanceWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class AttendanceWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(AttendanceWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $attendance is submitted.
     *
     * @param AttendanceWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(AttendanceWorkflowEvent $event)
    {
        $client = $event->attendance->client;
        Notification::send($client, new AttendanceWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $attendance is published.
     *
     * @param AttendanceWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(AttendanceWorkflowEvent $event)
    {
        $client = $event->attendance->client;
        Notification::send($client, new AttendanceWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $attendance is approved.
     *
     * @param AttendanceWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(AttendanceWorkflowEvent $event)
    {
        $client = $event->attendance->client;
        Notification::send($client, new AttendanceWorkflowNotification($event));
    }

    /**
     * Handles the $attendance workflow event as a listener.
     *
     * @param AttendanceWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(AttendanceWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
