<?php

namespace Bixo\Employee\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Employee\Events\LeaveAction as LeaveActionEvent;
use Bixo\Employee\Notifications\LeaveAction as LeaveActionNotification;
use Litepie\Actions\Concerns\AsAction;

class LeaveAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the LeaveActionEvent.
     *
     * @param   LeaveActionEvent  $event
     * @return mixed
     */
    public function handle(LeaveActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $leave.
     *
     * @param   LeaveActionEvent  $event
     * @return void
     */
    public function create(LeaveActionEvent $event)
    {
        $client = $event->leave->client;
        Notification::send($client, new LeaveActionNotification($event));
    }

    /**
     * Handle the LeaveActionEvent as a listener.
     *
     * @param   LeaveActionEvent  $event
     * @return mixed
     */
    public function asListener(LeaveActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   LeaveActionEvent  $event
     * @return bool
     */
    private function isAllowed(LeaveActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
