<?php

namespace Bixo\Employee\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Bixo\Employee\Events\LeaveWorkflow as LeaveWorkflowEvent;
use Bixo\Employee\Notifications\LeaveWorkflow as LeaveWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class LeaveWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(LeaveWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $leave is submitted.
     *
     * @param LeaveWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(LeaveWorkflowEvent $event)
    {
        $client = $event->leave->client;
        Notification::send($client, new LeaveWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $leave is published.
     *
     * @param LeaveWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(LeaveWorkflowEvent $event)
    {
        $client = $event->leave->client;
        Notification::send($client, new LeaveWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $leave is approved.
     *
     * @param LeaveWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(LeaveWorkflowEvent $event)
    {
        $client = $event->leave->client;
        Notification::send($client, new LeaveWorkflowNotification($event));
    }

    /**
     * Handles the $leave workflow event as a listener.
     *
     * @param LeaveWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(LeaveWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
