<?php
namespace Bixo\Employee\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Employee\Events\AttendanceAction as AttendanceActionEvent;
use Bixo\Employee\Models\Attendance;

class AttendanceAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $attendance;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param AttendanceActionEvent $attendance
     */
    public function __construct(AttendanceActionEvent $attendance)
    {
        $this->action = $event->action;
        $this->attendance = $attendance;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Attendance Approved - ' . config('app.name'))
            ->view('employee::attendance.email.action', ['data' => $this->attendance]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
