<?php
namespace Bixo\Employee\Notifications;

use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;
use Bixo\Employee\Events\LeaveAction as LeaveActionEvent;
use Bixo\Employee\Models\Leave;

class LeaveAction extends Notification implements ShouldQueue
{
    use Queueable;

    protected $event;
    protected $leave;
    protected $action;
    protected $request;

    /**
     * Create a new notification instance.
     *
     * @param LeaveActionEvent $leave
     */
    public function __construct(LeaveActionEvent $leave)
    {
        $this->action = $event->action;
        $this->leave = $leave;
        $this->request = $event->request;
        $this->event = $event;

    }

    /**
     * Get the mail representation of the notification.
     *
     * @param mixed $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new MailMessage)
            ->subject('Leave Approved - ' . config('app.name'))
            ->view('employee::leave.email.action', ['data' => $this->leave]);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param object $notifiable
     * @return array<int, string>
     */
    public function via(object $notifiable): array
    {
        return ['mail'];
    }
}
