<?php

namespace Bixo\Employee\Providers;

use Illuminate\Support\ServiceProvider;
use Bixo\Employee\Employees;

class EmployeeServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'employee');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'employee');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();

        $this->app->register(\Bixo\Employee\Providers\AuthServiceProvider::class);
        $this->app->register(\Bixo\Employee\Providers\RouteServiceProvider::class);
        $this->app->register(\Bixo\Employee\Providers\ActionServiceProvider::class);
        $this->app->register(\Bixo\Employee\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('bixo.employee', function($app)
        {
            return $this->app->make(Employee::class);
        });
    }

    /**
     * Merges user's and employee's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'bixo.employee'
        );
        
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/employee.php', 'bixo.employee.employee'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/document.php', 'bixo.employee.document'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/attendance.php', 'bixo.employee.attendance'
        );
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/leave.php', 'bixo.employee.leave'
        );
    }


    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['bixo.employee'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/' => config_path('bixo/employee')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/employee')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/employee')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
